#!/usr/share/venvs/netq-apps/bin/python

    # Initialize default values
    dump_to_file=
    export_file="/mnt/support/cassandra_diagnostic_data_$(date -d "today" +"%Y%m%d%H%M%S").txt"

    RED='\033[0;31m'
    YELLOW='\033[1;33m'
    NC='\033[0m' # No Color

    # Define function to print usage information
    print_usage() {
      echo "Usage: $0 [-f]"
      echo "  -f    print response to a file (default is stdout)"
      echo "  -h    prints this message"
    }

    # Parse command line options
    while getopts ":fh" opt; do
      case $opt in
        f) dump_to_file=true
        ;;
        h) print_usage
           exit 0
        ;;
        \?) echo "Invalid option -$OPTARG" >&2
            print_usage >&2
            exit 1
        ;;
      esac
    done

    function print_nodetool_information() {
        app_name=$(kubectl get pods -l app=cassandra -o jsonpath='{.items[0].metadata.name}')
        if test -z "$app_name"
        then
          echo -e "${RED}Cassandra POD not found"
          return -1
        fi

        echo -e "${YELLOW}Cluster information :"
        echo -e "${NC}"
        kubectl exec -it ${app_name} -- nodetool version
        echo
        kubectl exec -it ${app_name} -- nodetool status
        kubectl exec -it ${app_name} -- nodetool describecluster

        echo
        echo -e "${YELLOW}GC/throughput statistics :"
        echo -e "${NC}"
        echo
        echo "Garbage collection (GC) statistics : "
        kubectl exec -it ${app_name} -- nodetool gcstats
        echo

        kubectl exec -it ${app_name} -- nodetool getstreamthroughput
        kubectl exec -it ${app_name} -- nodetool getcompactionthroughput

        echo
        echo -e "${YELLOW}Network statistics : "
        echo -e "${NC}"
        echo
        kubectl exec -it ${app_name} -- nodetool netstats

        echo
        echo -e "${YELLOW}Service status :"
        echo -e "${NC}"
        echo "Backup is $(kubectl exec -it ${app_name} -- nodetool statusbackup)"
        echo "Native transport service is $(kubectl exec -it ${app_name} -- nodetool statusbinary)"
        echo "Gossip is $(kubectl exec -it ${app_name} -- nodetool statusgossip)"
        kubectl exec -it ${app_name} -- nodetool statushandoff

        echo
        echo -e "${YELLOW}Failure detection :"
        echo -e "${NC}"
        kubectl exec -it ${app_name} -- nodetool failuredetector

        echo
        echo -e "${YELLOW}Node info :"
        echo -e "${NC}"
        kubectl exec -it ${app_name} -- nodetool info

        echo
        echo -e "${YELLOW}Tables statistics :"
        echo -e "${NC}"
        kubectl exec -it ${app_name} -- nodetool tablestats

    }

    if [ "$dump_to_file" ]; then
        echo "Printing information to file $export_file ..." >&2
        print_nodetool_information >> $export_file
        result=$?
        if [ $result == 0 ]; then
            echo "Process completed successfully."
            exit $result
        else
            echo "Error occurred while collecting data. Exit code : $result."
            exit $result
        fi
    else
        echo "Printing information to STDOUT ..." >&2
        echo
        print_nodetool_information
    fi